@@ -1,4 +1,4 @@
-"mba.surf" <- function(xyz, no.X, no.Y,  n = 1, m = 1, h = 8, extend = FALSE, ...){
+"mba.surf" <- function(xyz, no.X, no.Y,  n = 1, m = 1, h = 8, extend = FALSE, sp=FALSE, ...){
 
   ####################################################
   ##Check for unused args
@@ -32,8 +32,24 @@
   storage.mode(xyz) <- "double"
   
   out <- .Call("MBASurf", xyz, as.integer(no.X), as.integer(no.Y), as.integer(m), as.integer(n), as.integer(h), as.integer(extend), as.integer(hpts))
+
+  if(sp){
+    xy <- expand.grid(out[["x"]], out[["y"]])
+    grid <- data.frame(z=matrix(out[["z"]], as.integer(length(out[["x"]])*length(out[["y"]])), 1),x=xy[,1], y=xy[,2])
+    coordinates(grid) = ~x+y
+    gridded(grid) <- TRUE
+  }else{
+    grid <- out[c("x","y","z")]
+  }
   
-  out1 <- list()
-  out1$xyz.est <- out[c("x","y","z")]
-  out1
+  out <- list()
+  out$xyz.est <- grid
+  out$no.X <- no.X
+  out$no.Y <- no.Y
+  out$n <- n
+  out$m <- m
+  out$h <- h
+  out$extend <- extend
+  out$sp <- sp
+  out
 }
